<?php
/**
* Plugin Name: Ideas
* Description: A blogging section with recipes, DIY and articles. Previously called "home-filter"
* Version: 2.0
* Author: Alejandro Torres
*/

class ideasAldi {

  var $hf_options;

  public function __construct() {

    $this->hf_options = get_option( 'hf_settings' ); // Saving options

    // Custom templates
    add_filter('single_template', array( $this, 'custom_single' ) );
    add_filter('archive_template',array( $this, 'custom_archive' ) );

    // STYLES
    add_action( 'wp_enqueue_scripts', array( $this, 'stylesScripts' ) );

    // SHORTCODES
    add_shortcode( "home-filter", array( $this, "print_code") );
    add_shortcode( "home-ideas", array( $this, "homeCode" ) );

    // AJAX Handlers
		add_action( 'wp_ajax_show_filter', array( $this, 'show_filter' ));
		add_action( 'wp_ajax_nopriv_show_filter', array( $this, 'show_filter' ));

    // Register taxonomies
    add_action( 'init', array( $this, 'register_taxonomies'));

    // Creating post type
    add_action( 'init', array( $this, 'create_custom_types' ) );

    // Renaming posts to "Inspiración"
    add_action( 'admin_menu', array( $this, 'revcon_change_post_label' ) );
    add_action( 'init', array( $this, 'revcon_change_post_object' ) );

    

  }

  public function stylesScripts() {

    // STYLES
    wp_enqueue_style( 'home-filter', plugin_dir_url( __FILE__ ) . "css/style.css", null, filemtime( plugin_dir_path( __FILE__ ) . "css/style.css" ) );

    // SCRIPTS
    wp_register_script( 'show-filter', plugin_dir_url( __FILE__ ) . 'js/script.js', array('jquery'), filemtime( plugin_dir_path( __FILE__ ) . "js/script.js" ), true );

    wp_localize_script( 'show-filter', 'S_Filter', array(
      // URL to wp-admin/admin-ajax.php to process the request

      'ajaxurl' => admin_url( 'admin-ajax.php' ),

      // generate a nonce with a unique ID "myajax-post-comment-nonce"
      // so that you can check it later when an AJAX request is sent
      'security' => wp_create_nonce( 'show-filter-ajax' ),

    ));

  }

  // SHORTCODE Code
  public function print_code() {

    wp_enqueue_script( 'show-filter' );

    // Getting filters from the URL
    $queryURL = parse_url( html_entity_decode( esc_url( add_query_arg( $arr_params ) ) ) );
    parse_str( $queryURL['query'], $getVar );
    $cat = $getVar['categ'];
    $page = $getVar['pag'];
    ?>

    <div class="up-pagination"></div>

    <!-- FILTER BODY -->
    <div class="filter-wrapper">

        <div class="container">

            <div>
                <?php
                // Selecting which category tags to show depending on the post type
                if( is_home() ) {
                  $this->tags_filter('categorias_emocionales',$cat);
                } elseif( is_post_type_archive("diy") ) {
                  $this->tags_filter('tipo_diy',$cat);
                }
                
                ?>
            </div>

        </div>

    </div>


    <!-- FILTER RESULTS -->
    <div class="hf-results">

        <div class="container">

            <div class="row hf-results-row">

            <!-- PRINTING THE RESULTS HERE -->
            <?php

            if( $cat=='' && $page=='' ) {
                $this->loop_filter(null,null,1);
            } else {

                if( is_home() ) {
                  $this->loop_filter($cat,"categorias_emocionales",$page);
                } elseif( is_post_type_archive("diy") ) {
                  $this->loop_filter($cat,"tipo_diy",$page);
                }
                
            }

            ?>

            </div>

        </div>

    </div>

    <?php
  }

  // Showing the tags of the filter. It requires the name of the category as argument
  public function tags_filter($cat_name,$c_cat=null) {

    $terms = get_terms( array (
        'taxonomy' => $cat_name,
        'hide_empty' => true
    ) );

    // Checking that there are terms in the category, and printing them
    if($terms) {

      if( $valN = get_term_by('id', $c_cat, $cat_name ) ) {
        $n = $valN->name;
      } else {
        $n = "Todos";
      }

      // List in mobile
      echo '<div class="hf-terms-select">';

      echo '<div class="dropdown dropdown-ideas">';
      echo '<button class="btn btn-default dropdown-toggle" type="button" id="dropdownMenuMobile" data-toggle="dropdown" aria-haspopup="true" aria-expanded="true">';
      echo '<span class="dropdown-title">'.$n.'</span>';
      echo '    <span class="caret"></span>';
      echo '</button>';
      echo '<ul class="dropdown-menu" aria-labelledby="dropdownMenuMobile">';
      echo '<li>Todos</li>';
      // Printing the terms
      foreach ( $terms as $term ) {
          $checked = (( $c_cat == $term->term_id ) ? 'checked' : '' );
          echo '<li data-val="'.$term->term_id.'" class="'.$checked.'">'.$term->name.'</li>';
      }
      
      echo '</ul>';
      echo '</div>';

      echo '</div>';

      echo $sel;

      // List in desktop
      echo "<ul class='hf-terms-list' data-tipo='".$cat_name."'>";
      if( $c_cat=="" ) {
        echo "<li><a class='active'>Todos</a></li>";
      } else {
        echo "<li><a>Todos</a></li>";
      }
      
      foreach ( $terms as $term ) {

        echo "<li><a data-cat='".$term->term_id."'".(( $c_cat == $term->term_id ) ? ' class="active"' : '' ).">".$term->name."</a></li>";

      }

      echo "</ul>";

    } else {

      _e("Lo sentimos, no hay términos en la categoría seleccionada.");

    }

  }

  // AJAX answer to the filter buttons
  public function show_filter() {

    check_ajax_referer( 'show-filter-ajax', 'security' );

    $this->loop_filter($_POST['term_code'],$_POST['term_cat'], $_POST['paged']);

    die();
  }

  // Query retrieving the posts
  public function loop_filter( $codeterm, $term_cat, $paged=1 ) {

    $postspp = get_option( 'posts_per_page' );
    
    if( is_home() || $term_cat == 'categorias_emocionales' ) {
      $post_t = "post";
    } elseif ( is_post_type_archive("diy") || $term_cat == 'tipo_diy' ) {
      $post_t = "diy";
    }

    if( $codeterm!='' ) {

      $args = array (
        'showposts' => $postspp,
        'paged' => $paged,
        'tax_query' => array(
          array(
            'taxonomy' => $term_cat,
            'field' => 'term_id',
            'terms' => $codeterm
          )
        ),
        'post_status' => 'publish',
        'post_type' => $post_t
      );

    } else {

      $args = array (
        'showposts' => $postspp,
        'paged' => $paged,
        'post_status' => 'publish',
        'post_type' => $post_t
      );

    }

    $params  = '';

    if( $codeterm != '' || $paged != '' ) {

        if( $codeterm == '' && $paged != '' ) {
            $params = '?pag='.$paged;
        } elseif ( $codeterm != '' && $paged == '' ) {
            $params = '?categ='.$codeterm;
        } else {
            $params = '?categ='.$codeterm."&pag=".$paged;
        }

    }

    $query = new WP_Query( $args );


    if( $query->have_posts() ) :
      $i=1;
      // Printing the posts
      while( $query->have_posts()) {
        $query->the_post();

        /************** 2 COLUMNS *****************/
        
        echo '<div class="col-xs-12 col-sm-12 col-md-6 hf-post">';
        include('template-article-archive.php');
        echo '</div>';

        if($i%2==0) {
          echo "<span class='clearfix'></span>";
        }
        echo "<span class='clearfix visible-sm'></span>";

        $i++;

      }

      echo "<span class='clearfix'></span>";

      numeric_pagination($query,$paged,true,0);
      wp_reset_postdata();

    else :
      echo "no"; // For Javascript error handling
    endif;
  }

  // Adding new taxonomies to posts
  public function register_taxonomies() {

    register_taxonomy(
  		'categorias_emocionales',
  		'post',
  		array(
  			'labels' => array(
          'name' => __( 'Categorías Emocionales' ),
          'singular_name' => __("Categoría emocional"),
          'menu_name' => __( 'Categorías Emocionales' ),
          'add_new_item' => __( 'Añadir Categoría emocional' ),
        ),
  			'rewrite' => array( 'slug' => 'categorias-emocionales' ),
        'hierarchical' => true
  		)
  	);

    register_taxonomy(
      'tipo_diy',
      'diy',
      array(
        'label' => __( 'Tipo' ),
        'rewrite' => array( 'slug' => 'tipo-manualidades' ),
        'hierarchical' => true
      )
    );
    
    unregister_taxonomy_for_object_type( 'category', 'post' );

  }

  // It creates the custom type "Recetas"
  public function create_custom_types () {

    register_post_type( 'diy',
        array(
          'labels' => array(
              'name' => __( 'Manualidades' ),
              'singular_name' => __( 'Manualidad' )
          ),
          'public' => true,
          'has_archive' => true,
          'supports' => array( 'title','thumbnail','excerpt','editor' ),
          'menu_icon'   => 'dashicons-hammer',
          'rewrite' => array( 'slug' => 'manualidades' ),
        )
    );

  }

  /* Filter the single-template with our custom function */
  public function custom_single( $single ) {

      global $wp_query, $post;

      /* Checks for single template by post type */
      // Recipes
      if ($post->post_type == "receta") {

          if(file_exists( plugin_dir_path( __FILE__ ) . 'single-receta.php' )) {
            return plugin_dir_path( __FILE__ ) . 'single-receta.php';
          }
              
      }

      // DIY
      if ( $post->post_type == "diy" ) {
        
          if(file_exists( plugin_dir_path( __FILE__ ) . 'single-diy.php' )) {
            return plugin_dir_path( __FILE__ ) . 'single-diy.php';
          }
              
      }

      // Posts
      if ( $post->post_type == "post" ) {
        
          if(file_exists( plugin_dir_path( __FILE__ ) . 'single-post.php' )) {
            return plugin_dir_path( __FILE__ ) . 'single-post.php';
          }
              
      }
      return $single;

  }

  /* Filter the archive-template with our custom function */
  public function custom_archive( $template ) {

    // Recipes
    if( is_post_type_archive('receta') ) {
      
      $theme_files = array('archive-receta.php');
      $exists_in_theme = locate_template( $theme_files, false);

      if( $exists_in_theme == '' ) {

        return plugin_dir_path( __FILE__ ) . 'archive-receta.php';

      }

    }

    // DIY
    if( is_post_type_archive('diy') ) {

      $theme_files = array('archive-diy.php');
      $exists_in_theme = locate_template( $theme_files, false);

      if( $exists_in_theme == '' ) {

        return plugin_dir_path( __FILE__ ) . 'archive-diy.php';

      }

    }

    return $template;

  }

  // This code prints a banner with one example of each type
  public function homeCode() {
  ?>

    <div class="home-ideas">

      <?php if (get_field('hi_tit') ) { ?>
        <h3 class="home-ideas-h3"><span><?php echo get_field("hi_tit"); ?></span></h3>
      <?php } ?>

      <?php
      $summary = false;
      if( get_field( 'hi_post_sum' ) ) {
        $summary = true;
      }

      $button = false;
      if( get_field( 'hi_post_btn' ) ) {
        $button = true;
      }
      ?>

      <div class="all-blocks row">

        <!-- INSPIRACIÓN -->
        <div class="col-xs-12 col-sm-4 hf-post" id="home-read-posts">
          <div class="hf-post-wrapper">
          <?php
          $type = "Inspiración";
          $args = array (
            'showposts' => 1,
            'post_status' => 'publish',
            'post_type' => 'post'
          );

          if( get_field('hi_blog_single') ) {
            $args['p'] = get_field('hi_blog_code')->ID;
          }

          $query = new WP_Query( $args );

          if( $query->have_posts() ) :
            $i=1;
            // Printing the posts
            while( $query->have_posts() ) { $query->the_post();
              include('template-article-home.php');
            }

          endif;

          wp_reset_postdata();
          ?>
          </div>

        </div>

        <!-- RECETA -->
        <div class="col-xs-12 col-sm-4 hf-post" id="home-read-recipes">
          <div class="hf-post-wrapper">

          <?php
          $type = "Recetas";
          $args = array (
            'showposts' => 1,
            'post_status' => 'publish',
            'post_type' => 'receta'
          );

          if( get_field('hi_rec_single') ) {
            $args['p'] = get_field('hi_rec_code')->ID;
          }

          $query = new WP_Query( $args );

          if( $query->have_posts() ) :
            $i=1;
            // Printing the posts
            while( $query->have_posts() ) { $query->the_post();
              include('template-article-home.php');
            }

          endif;

          wp_reset_postdata();
          ?>
          </div>

        </div>

        <!-- MANUALIDAD -->
        <div class="col-xs-12 col-sm-4 hf-post" id="home-read-diy">
          <div class="hf-post-wrapper">
          <?php
          $type = "Manualidades";
          $args = array (
            'showposts' => 1,
            'post_status' => 'publish',
            'post_type' => 'diy'
          );

          if( get_field('hi_diy_single') ) {
            $args['p'] = get_field('hi_diy_code')->ID;
          }

          $query = new WP_Query( $args );

          if( $query->have_posts() ) :
            $i=1;
            // Printing the posts
            while( $query->have_posts() ) { $query->the_post();
              include('template-article-home.php');
            }

          endif;

          wp_reset_postdata();
          ?>
          </div>
        </div>

      </div>

    </div>

    <?php
    wp_reset_postdata();
  }

  // Renaming posts to "Inspiración"
  public function revcon_change_post_label() {
      global $menu;
      global $submenu;
      $menu[5][0] = 'Inspiración';
      $submenu['edit.php'][5][0] = 'Inspiración';
      $submenu['edit.php'][10][0] = 'Añadir inspiración';
      $submenu['edit.php'][16][0] = 'Nuevas etiquetas';
  }
  public function revcon_change_post_object() {
      global $wp_post_types;
      $labels = &$wp_post_types['post']->labels;
      $labels->name = 'Inspiración';
      $labels->singular_name = 'Inspiración';
      $labels->add_new = 'Añadir inspiración';
      $labels->add_new_item = 'Añadir inspiración';
      $labels->edit_item = 'Editar inspiración';
      $labels->new_item = 'Inspiración';
      $labels->view_item = 'Ver inspiración';
      $labels->search_items = 'Buscar inspiración';
      $labels->not_found = 'No se ha encontrado inspiración';
      $labels->not_found_in_trash = 'No se ha encontrado inspiración en la papelera';
      $labels->all_items = 'Toda la inspiración';
      $labels->menu_name = 'Inspiración';
      $labels->name_admin_bar = 'Inspiración';
      $wp_post_types['post']->menu_icon = 'dashicons-format-status';
  }
  

}

$hf = new ideasAldi();

// Incluyendo clases de extensión
include ("recetas.php");
include ("advanced-custom-fields.php");
